@@ -1,4 +1,4 @@
-##' @export
+#' @export
 setGeneric("values", function (x) standardGeneric("values"))
 setGeneric("values<-", function (x, value) standardGeneric("values<-"))
 
@@ -37,6 +37,9 @@ setGeneric("descriptions<-",
     function (x, value) standardGeneric("descriptions<-"), signature="x")
 setGeneric("emails", function (x) standardGeneric("emails"))
 setGeneric("email", function (x) standardGeneric("email"))
+setGeneric("notes", function (x) standardGeneric("notes"))
+setGeneric("notes<-", function (x, value) standardGeneric("notes<-"),
+    signature="x")
 
 setGeneric("types", function (x) standardGeneric("types"))
 setGeneric("timestamps", function (x) standardGeneric("timestamps"))
@@ -63,7 +66,6 @@ setGeneric("self", function (x) standardGeneric("self"))
 setGeneric("refresh", function (x) standardGeneric("refresh"))
 setGeneric("delete", function (x, ...) standardGeneric("delete"),
     signature="x")
-setGeneric("readonly<-", function (x, value) standardGeneric("readonly<-"))
 setGeneric("entities", function (x, ...) standardGeneric("entities"))
 setGeneric("entities<-", function (x, value) standardGeneric("entities<-"))
 setGeneric("tuple", function (x) standardGeneric("tuple"))
@@ -127,17 +129,17 @@ setGeneric("round")
 
 setGeneric("subset")
 
-##' Generic method for converting objects to Crunch representations
-##'
-##' If you have other object types you wish to convert to Crunch variables,
-##' you can declare methods for \code{toVariable}
-##' @param x the object
-##' @param ... additional arguments
-##' @return a list object suitable for POSTing to the Crunch API. See the API
-##' documentation for specifications.
-##' @rdname toVariable
-##' @aliases toVariable
-##' @export
+#' Generic method for converting objects to Crunch representations
+#'
+#' If you have other object types you wish to convert to Crunch variables,
+#' you can declare methods for \code{toVariable}
+#' @param x the object
+#' @param ... additional arguments
+#' @return a list object suitable for POSTing to the Crunch API. See the API
+#' documentation for specifications.
+#' @rdname toVariable
+#' @aliases toVariable
+#' @export
 setGeneric("toVariable", function (x, ...) standardGeneric("toVariable"))
 
 setGeneric("lapply")
@@ -148,27 +150,27 @@ setGeneric("write.csv")
 
 setGeneric("zcl", function (x) standardGeneric("zcl"))
 
-##' toJSON methods for Crunch objects
-##'
-##' \code{crunch} uses the \code{jsonlite} package for (de)serialization of
-##' JSON. Unlike \code{RJSONIO}'s \code{toJSON}, \code{\link[jsonlite]{toJSON}}
-##' does not allow for defining S4 methods for other object types. So,
-##' \code{crunch::toJSON} wraps \code{jsonprep}, which exists to translate
-##' objects to base R objects, which \code{jsonlite::toJSON} can handle.
-##' \code{jsonprep} is defined as an S4 generic, and it is exported (unlike
-##' code{jsonlite::asJSON}), so you can define methods for it if you have other
-##' objects that you want to successfully serialize to JSON.
-##'
-##' @param x the object
-##' @param ... additional arguments
-##' @return \code{jsonprep} returns a base R object that \code{jsonlite::toJSON}
-##' can handle. \code{toJSON} returns the JSON-serialized character object.
-##' @name tojson-crunch
-##' @seealso \code{\link[jsonlite]{toJSON}}
+#' toJSON methods for Crunch objects
+#'
+#' \code{crunch} uses the \code{jsonlite} package for (de)serialization of
+#' JSON. Unlike \code{RJSONIO}'s \code{toJSON}, \code{\link[jsonlite]{toJSON}}
+#' does not allow for defining S4 methods for other object types. So,
+#' \code{crunch::toJSON} wraps \code{jsonprep}, which exists to translate
+#' objects to base R objects, which \code{jsonlite::toJSON} can handle.
+#' \code{jsonprep} is defined as an S4 generic, and it is exported (unlike
+#' code{jsonlite::asJSON}), so you can define methods for it if you have other
+#' objects that you want to successfully serialize to JSON.
+#'
+#' @param x the object
+#' @param ... additional arguments
+#' @return \code{jsonprep} returns a base R object that \code{jsonlite::toJSON}
+#' can handle. \code{toJSON} returns the JSON-serialized character object.
+#' @name tojson-crunch
+#' @seealso \code{\link[jsonlite]{toJSON}}
 NULL
 
-##' @rdname tojson-crunch
-##' @export
+#' @rdname tojson-crunch
+#' @export
 setGeneric("jsonprep", function (x, ...) standardGeneric("jsonprep"))
 
 setGeneric("getShowContent",
