@@ -1,15 +1,15 @@
-##' Add multiple variables to a dataset
-##'
-##' This function lets you add more than one variable at a time to a dataset.
-##' If you have multiple variables to add, this function will be faster than
-##' doing \code{ds$var <- value} assignment because it doesn't refresh the
-##' dataset's state in between variable POST requests.
-##' @param dataset a CrunchDataset
-##' @param ... \code{\link{VariableDefinition}}s or a list of
-##' VariableDefinitions.
-##' @return \code{dataset} with the new variables added (invisibly)
-##' @export
-##' @importFrom httpcache halt
+#' Add multiple variables to a dataset
+#'
+#' This function lets you add more than one variable at a time to a dataset.
+#' If you have multiple variables to add, this function will be faster than
+#' doing \code{ds$var <- value} assignment because it doesn't refresh the
+#' dataset's state in between variable POST requests.
+#' @param dataset a CrunchDataset
+#' @param ... \code{\link{VariableDefinition}}s or a list of
+#' VariableDefinitions.
+#' @return \code{dataset} with the new variables added (invisibly)
+#' @export
+#' @importFrom httpcache halt
 addVariables <- function (dataset, ...) {
     var_catalog_url <- shojiURL(dataset, "catalogs", "variables")
 
@@ -29,8 +29,7 @@ addVariables <- function (dataset, ...) {
         halt("Must supply VariableDefinitions")
     }
     ## Check that if values specified, they have the right length
-    vardefs <- lapply(vardefs, validateVarDefRows,
-        numrows=getNrow(dataset, filtered=FALSE))
+    vardefs <- lapply(vardefs, validateVarDefRows, numrows=getNrow(dataset))
 
     ## TODO: check array subvariable rows similarly. and/or pull out and cbind
     ## to a single parent-level "values" column.
