@@ -38,34 +38,34 @@ concatenateCategories <- function (...) {
     return(Categories(data=do.call(c, dots)))
 }
 
-##' S3 method to concatenate Categories and Category objects
-##'
-##' @param ... see \code{\link[base]{c}}
-##' @return An object of class \code{\link{Categories}}
-##' @name c-categories
-##' @export
-##' @examples
-##' cat.a <- Category(name="First", id=1, numeric_value=1, missing=FALSE)
-##' cat.b <- Category(name="Second", id=2)
-##' cat.c <- Category(name="Third", id=3, missing=TRUE)
-##' cats.1 <- Categories(cat.a, cat.b)
-##' identical(cats.1, c(cat.a, cat.b))
-##' identical(c(cats.1, cat.c), Categories(cat.a, cat.b, cat.c))
+#' S3 method to concatenate Categories and Category objects
+#'
+#' @param ... see \code{\link[base]{c}}
+#' @return An object of class \code{\link{Categories}}
+#' @name c-categories
+#' @export
+#' @examples
+#' cat.a <- Category(name="First", id=1, numeric_value=1, missing=FALSE)
+#' cat.b <- Category(name="Second", id=2)
+#' cat.c <- Category(name="Third", id=3, missing=TRUE)
+#' cats.1 <- Categories(cat.a, cat.b)
+#' identical(cats.1, c(cat.a, cat.b))
+#' identical(c(cats.1, cat.c), Categories(cat.a, cat.b, cat.c))
 c.Categories <- concatenateCategories
 
-##' @rdname c-categories
-##' @export
+#' @rdname c-categories
+#' @export
 c.Category <- concatenateCategories
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("[", c("Categories", "ANY"), function (x, i, ...) {
     x@.Data <- x@.Data[i]
     return(x)
 })
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("[", c("Categories", "numeric"), function (x, i, ...) {
     invalid.indices <- setdiff(abs(i), seq_along(x@.Data))
     if (length(invalid.indices)) {
@@ -75,23 +75,23 @@ setMethod("[", c("Categories", "numeric"), function (x, i, ...) {
     return(x)
 })
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("[<-", c("Categories", "ANY"), function (x, i, ..., value) {
     x@.Data[i] <- Categories(data=value)
     return(x)
 })
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("names", "Categories", function (x) vapply(x, name, character(1)))
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("values", "Categories", function (x) vapply(x, value, numeric(1)))
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("ids", "Categories", function (x) vapply(x, id, integer(1)))
 
 setNames <- function (x, value) {
@@ -99,7 +99,11 @@ setNames <- function (x, value) {
         halt('Names must be of class "character"')
     }
     if (!identical(length(x), length(value))) {
-        halt("Invalid names: supplied ", length(value), " names for ", length(x), " categories")
+        halt("Invalid names: supplied ", length(value), " names for ",
+            length(x), " categories")
+    }
+    if (any(is.na(value))) {
+        halt("Category names must be non-missing")
     }
     x[] <- mapply(setName, x, value=value, SIMPLIFY=FALSE)
     return(x)
@@ -109,14 +113,14 @@ setValues <- function (x, value) {
     return(x)
 }
 
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("names<-", "Categories", setNames)
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("values<-", "Categories", setValues)
-##' @rdname Categories
-##' @export
+#' @rdname Categories
+#' @export
 setMethod("ids<-", "Categories", function (x, value) {
     if (!identical(ids(x), value)) {
         halt("Cannot modify category ids")
@@ -135,71 +139,80 @@ setMethod("ids<-", "Categories", function (x, value) {
     return(object)
 }
 
-##' Omit missing categories
-##' @param object Categories
-##' @param ... additional arguments, ignored
-##' @return \code{object} with any categories that have missing: TRUE excluded
-##' @name na-omit-categories
+#' Omit missing categories
+#' @param object Categories
+#' @param ... additional arguments, ignored
+#' @return \code{object} with any categories that have missing: TRUE excluded
+#' @name na-omit-categories
 NULL
 
-##' @rdname na-omit-categories
-##' @export
+#' @rdname na-omit-categories
+#' @export
 setMethod("na.omit", "Categories", function (object, ...) {
     Categories(data=.na.omit.categories(object))
 })
 
-##' is.na for Categories
-##'
-##' @param x Categories or a single Category
-##' @param value To change the missingness of categories, supply either (1)
-##' a logical vector of equal length of the categories (or length 1 for the
-##' Category method), or (2) the names of the categories to mark as missing.
-##' If supplying the latter, any categories already indicated as missing will
-##' remain missing.
-##' @return Getters return logical, a named vector in the case of the Categories
-##' method; setters return \code{x} duly modified.
-##' @name is-na-categories
+#' is.na for Categories
+#'
+#' @param x Categories or a single Category
+#' @param value To change the missingness of categories, supply either (1)
+#' a logical vector of equal length of the categories (or length 1 for the
+#' Category method), or (2) the names of the categories to mark as missing.
+#' If supplying the latter, any categories already indicated as missing will
+#' remain missing.
+#' @return Getters return logical, a named vector in the case of the Categories
+#' method; setters return \code{x} duly modified.
+#' @name is-na-categories
 NULL
 
-##' @rdname is-na-categories
-##' @aliases is-na-categories
-##' @export
+#' @rdname is-na-categories
+#' @aliases is-na-categories
+#' @export
 setMethod("is.na", "Categories", function (x) structure(vapply(x, is.na, logical(1), USE.NAMES=FALSE), .Names=names(x)))
 
 n2i <- function (x, cats, strict=TRUE) {
     ## Convert x from category names to the corresponding category ids
     out <- ids(cats)[match(x, names(cats))]
-    if (strict && any(is.na(out))) {
-        halt(ifelse(sum(is.na(out)) > 1, "Categories", "Category"),
-            " not found: ", serialPaste(dQuote(x[is.na(out)])))
-    }
+    out <- handleMissingCategoryLookup(out, x, strict)
     return(out)
 }
 
 i2n <- function (x, cats, strict=TRUE) {
     ## Convert x from category ids to the corresponding category names
     out <- names(cats)[match(x, ids(cats))]
-    if (strict && any(is.na(out))) {
-        halt(ifelse(sum(is.na(out)) > 1, "Categories", "Category"),
-            " not found: ", serialPaste(dQuote(x[is.na(out)])))
-    }
+    out <- handleMissingCategoryLookup(out, x, strict)
     return(out)
 }
 
-##' @rdname is-na-categories
-##' @export
+handleMissingCategoryLookup <- function (result, original, strict=TRUE) {
+    bad <- is.na(result)
+    if (any(bad)) {
+        msg <- paste(ifelse(sum(bad) > 1, "Categories", "Category"),
+            "not found:", serialPaste(dQuote(original[bad])))
+        if (strict) {
+            ## Break
+            halt(msg)
+        } else {
+            ## Warn and drop
+            msg <- paste0(msg, ". Dropping.")
+            warning(msg, call.=FALSE)
+            result <- na.omit(result)
+        }
+    }
+    return(result)
+}
+
+#' @rdname is-na-categories
+#' @export
 setMethod("is.na<-", c("Categories", "character"), function (x, value) {
     ix <- match(value, names(x))
-    if (any(is.na(ix))) {
-        halt(ifelse(sum(is.na(ix)) > 1, "Categories", "Category"),
-            " not found: ", serialPaste(dQuote(value[is.na(ix)])))
-    }
+    out <- handleMissingCategoryLookup(ix, value, strict=TRUE)
     x[ix] <- lapply(x[ix], `is.na<-`, value=TRUE)
     return(x)
 })
 
-##' @rdname is-na-categories
-##' @export
+#' @rdname is-na-categories
+#' @export
 setMethod("is.na<-", c("Categories", "logical"), function (x, value) {
     stopifnot(length(x) == length(value))
     x@.Data <- mapply(function (x, value) {
