@@ -1,20 +1,20 @@
-##' Crunch xtabs: Crosstab and otherwise aggregate variables in a Crunch Dataset
-##'
-##' Create a contingency table or other aggregation from cross-classifying
-##' variables in a CrunchDataset.
-##'
-##' @param formula an object of class 'formula' object with the
-##' cross-classifying variables, separated by '+', on the right hand side.
-##' Compare to \code{\link[stats]{xtabs}}.
-##' @param data an object of class \code{CrunchDataset}
-##' @param weight a CrunchVariable that has been designated as a potential
-##' weight variable for \code{data}, or \code{NULL} for unweighted results.
-##' Default is the currently applied weight, \code{\link{weight}(data)}.
-##' @param useNA whether to include missing values in tabular results. See
-##' \code{\link[base]{table}}.
-##' @return an object of class \code{CrunchCube}
-##' @importFrom stats as.formula terms
-##' @export
+#' Crunch xtabs: Crosstab and otherwise aggregate variables in a Crunch Dataset
+#'
+#' Create a contingency table or other aggregation from cross-classifying
+#' variables in a CrunchDataset.
+#'
+#' @param formula an object of class 'formula' object with the
+#' cross-classifying variables, separated by '+', on the right hand side.
+#' Compare to \code{\link[stats]{xtabs}}.
+#' @param data an object of class \code{CrunchDataset}
+#' @param weight a CrunchVariable that has been designated as a potential
+#' weight variable for \code{data}, or \code{NULL} for unweighted results.
+#' Default is the currently applied weight, \code{\link{weight}(data)}.
+#' @param useNA whether to include missing values in tabular results. See
+#' \code{\link[base]{table}}.
+#' @return an object of class \code{CrunchCube}
+#' @importFrom stats as.formula terms
+#' @export
 crtabs <- function (formula, data, weight=crunch::weight(data),
                      useNA=c("no", "ifany", "always")) {
     ## Validate "formula"
@@ -122,14 +122,23 @@ registerCubeFunctions <- function (varnames) {
     ## that has the cube functions. This version just checks for name collisions
     ## and errors if there is one.
 
+    numfunc <- function (func) {
+        force(func)
+        return(function (x) {
+            if (is.Categorical(x)) {
+                ## "Cast" it on the fly
+                x <- zfunc("cast", x, "numeric")
+            }
+            zfunc(func, x)
+        })
+    }
+
     funcs <- list(
-        mean=function (x) zfunc("cube_mean", x),
-        min=function (x) zfunc("cube_min", x),
-        max=function (x) zfunc("cube_max", x),
-        # median=function (x) zfunc("cube_quantile", x, .5),
-        # quantile=function (x, q) zfunc("cube_quantile", x, q),
-        sd=function (x) zfunc("cube_stddev", x),
-        sum=function (x) zfunc("cube_sum", x)
+        mean=numfunc("cube_mean"),
+        min=numfunc("cube_min"),
+        max=numfunc("cube_max"),
+        sd=numfunc("cube_stddev"),
+        sum=numfunc("cube_sum")
     )
 
     overlap <- intersect(varnames, names(funcs))
