@@ -1,26 +1,28 @@
-##' Construct Crunch Expressions
-##'
-##' Crunch Expressions, i.e. \code{CrunchExpr} and \code{CrunchLogicalExpr},
-##' encapuslate derivations of Crunch variables, which are only evaluated when
-##' passed to a function like \code{as.vector}. They allow you to compose
-##' functional expressions of variables and evaluate them against the server
-##' only when appropriate.
-##'
-##' @param x an input
-##' @param table For \code{\%in\%}. See \code{\link[base]{match}}
-##' @param resolution For \code{rollup}. Either \code{NULL} or a character in
-##' c("Y", "Q", "M", "W", "D", "h", "m", "s", "ms") indicating the unit of
-##' time at which a Datetime variable should be aggregated. If \code{NULL},
-##' the server will determine an appropriate resolution based on the range of
-##' the data.
-##' @return Most functions return a CrunchExpr or CrunchLogicalExpr.
-##' \code{as.vector} returns an R vector.
-##' @aliases expressions
-##' @name expressions
+#' Construct Crunch Expressions
+#'
+#' Crunch Expressions, i.e. \code{CrunchExpr} and \code{CrunchLogicalExpr},
+#' encapuslate derivations of Crunch variables, which are only evaluated when
+#' passed to a function like \code{as.vector}. They allow you to compose
+#' functional expressions of variables and evaluate them against the server
+#' only when appropriate.
+#'
+#' @param x an input
+#' @param e1 an input
+#' @param e2 an input
+#' @param table For \code{\%in\%}. See \code{\link[base]{match}}
+#' @param resolution For \code{rollup}. Either \code{NULL} or a character in
+#' c("Y", "Q", "M", "W", "D", "h", "m", "s", "ms") indicating the unit of
+#' time at which a Datetime variable should be aggregated. If \code{NULL},
+#' the server will determine an appropriate resolution based on the range of
+#' the data.
+#' @return Most functions return a CrunchExpr or CrunchLogicalExpr.
+#' \code{as.vector} returns an R vector.
+#' @aliases expressions
+#' @name expressions
 NULL
 
-##' @rdname variable-to-R
-##' @export
+#' @rdname variable-to-R
+#' @export
 setMethod("as.vector", "CrunchExpr", function (x, mode) {
     payload <- list(query=toJSON(list(out=zcl(x))))
     if (length(x@filter)) {
@@ -30,15 +32,14 @@ setMethod("as.vector", "CrunchExpr", function (x, mode) {
     }
     out <- paginatedGET(paste0(x@dataset_url, "table/"),
         query=payload, table=TRUE)
-        # limit=10000000000) ## Because server doesn't accept pagination yet
     ## pass in the variable metadata to the column parser
     variable <- VariableEntity(structure(list(body=out$metadata$out),
         class="shoji"))
     return(columnParser(out$metadata$out$type, mode)(out$data$out, variable))
 })
 
-##' @rdname toVariable
-##' @export
+#' @rdname toVariable
+#' @export
 setMethod("toVariable", "CrunchExpr", function (x, ...) {
     structure(list(expr=zcl(x), ...), class="VariableDefinition")
 })
@@ -58,25 +59,34 @@ math.exp <- function (e1, e2, operator) {
     } else {
         Constructor <- CrunchExpr
     }
-    ## TODO: if e1 and e2 have filters, pass them along, and if both do,
-    ## make sure that they're the same
-    return(Constructor(expression=ex, dataset_url=ds.url))
+
+    ## If either e1 or e2 are Crunch objects with filters, pass those along,
+    ## and if both do, make sure that they're the same
+    f1 <- try(activeFilter(e1), silent=TRUE)
+    f2 <- try(activeFilter(e2), silent=TRUE)
+    if (is.error(f1)) {
+        if (is.error(f2)) {
+            ## Neither object is a Crunch object? We shouldn't be here.
+            filt <- NULL
+        } else {
+            filt <- f2
+        }
+    } else if (is.error(f2)) {
+        filt <- f1
+    } else {
+        ## Ok: Both are Crunch objects. Reject if filters aren't identical.
+        if (!identical(f1, f2)) {
+            halt("Cannot combine expressions with different filters")
+        }
+        filt <- f1
+    }
+    out <- Constructor(expression=ex, dataset_url=ds.url)
+    activeFilter(out) <- filt
+    return(out)
 }
 
-vxr <- function (i) {
-    ## Create math.exp of Variable x R.object
-    force(i)
-    return(function (e1, e2) math.exp(e1, e2, i))
-}
-
-rxv <- function (i) {
-    ## Create math.exp of R.object x Variable
-    force(i)
-    return(function (e1, e2) math.exp(e1, e2, i))
-}
-
-vxv <- function (i) {
-    ## Create math.exp of two non-R.objects
+crunch.ops <- function (i) {
+    ## Create math.exp of Variable x R.object, R.object x Variable, or V x V
     force(i)
     return(function (e1, e2) math.exp(e1, e2, i))
 }
@@ -86,7 +96,8 @@ vxv <- function (i) {
     c("NumericVariable", "numeric"),
     c("DatetimeVariable", "Date"),
     c("DatetimeVariable", "POSIXt"),
-    c("CategoricalVariable", "numeric")
+    c("DatetimeVariable", "character"), ## TODO: validate that the "character" is valid 8601?
+    c("CategoricalVariable", "numeric") ## TODO: add cast(x, "numeric") around var for this?
 )
 
 .rtypes <- unique(vapply(.sigs, function (a) a[[2]], character(1)))
@@ -96,65 +107,35 @@ vxv <- function (i) {
 
 for (i in c("+", "-", "*", "/", "<", ">", ">=", "<=")) {
     for (j in .nomath) {
-        setMethod(i, .sigs[[j]], vxr(i))
-        setMethod(i, rev(.sigs[[j]]), rxv(i))
+        setMethod(i, .sigs[[j]], crunch.ops(i))
+        setMethod(i, rev(.sigs[[j]]), crunch.ops(i))
     }
     for (j in setdiff(.rtypes, "character")) {
-        setMethod(i, c("CrunchExpr", j), vxv(i))
-        setMethod(i, c(j, "CrunchExpr"), vxv(i))
+        setMethod(i, c("CrunchExpr", j), crunch.ops(i))
+        setMethod(i, c(j, "CrunchExpr"), crunch.ops(i))
     }
-    setMethod(i, c("CrunchVariable", "CrunchVariable"), vxv(i))
-    setMethod(i, c("CrunchExpr", "CrunchVariable"), vxv(i))
-    setMethod(i, c("CrunchVariable", "CrunchExpr"), vxv(i))
+    setMethod(i, c("CrunchVariable", "CrunchVariable"), crunch.ops(i))
+    setMethod(i, c("CrunchExpr", "CrunchVariable"), crunch.ops(i))
+    setMethod(i, c("CrunchVariable", "CrunchExpr"), crunch.ops(i))
+    setMethod(i, c("CrunchExpr", "CrunchExpr"), crunch.ops(i))
 }
 
-.catmeth <- function (i, Rarg=1) {
-    force(i)
-    force(Rarg)
-    return(function (e1, e2) {
-        if (Rarg == 1) {
-            e1 <- n2i(as.character(e1), categories(e2))
-        } else {
-            e2 <- n2i(as.character(e2), categories(e1))
-        }
-        return(math.exp(e1, e2, i))
-    })
-}
+setMethod("&", c("CrunchExpr", "CrunchExpr"), crunch.ops("and"))
+setMethod("&", c("logical", "CrunchExpr"), crunch.ops("and"))
+setMethod("&", c("CrunchExpr", "logical"), crunch.ops("and"))
+setMethod("|", c("CrunchExpr", "CrunchExpr"), crunch.ops("or"))
+setMethod("|", c("logical", "CrunchExpr"), crunch.ops("or"))
+setMethod("|", c("CrunchExpr", "logical"), crunch.ops("or"))
 
-for (i in c("==", "!=")) {
-    for (j in seq_along(.sigs)) {
-        setMethod(i, .sigs[[j]], vxr(i))
-        setMethod(i, rev(.sigs[[j]]), rxv(i))
-    }
-    setMethod(i, c("CategoricalVariable", "character"), .catmeth(i, 2))
-    setMethod(i, c("CategoricalVariable", "factor"), .catmeth(i, 2))
-    setMethod(i, c("character", "CategoricalVariable"), .catmeth(i, 1))
-    setMethod(i, c("factor", "CategoricalVariable"), .catmeth(i, i))
-    for (j in .rtypes) {
-        setMethod(i, c("CrunchExpr", j), vxv(i))
-        setMethod(i, c(j, "CrunchExpr"), vxv(i))
-    }
-    setMethod(i, c("CrunchVariable", "CrunchVariable"), vxv(i))
-    setMethod(i, c("CrunchExpr", "CrunchVariable"), vxv(i))
-    setMethod(i, c("CrunchVariable", "CrunchExpr"), vxv(i))
-}
-
-setMethod("&", c("CrunchExpr", "CrunchExpr"), vxv("and"))
-setMethod("&", c("logical", "CrunchExpr"), vxv("and"))
-setMethod("&", c("CrunchExpr", "logical"), vxv("and"))
-setMethod("|", c("CrunchExpr", "CrunchExpr"), vxv("or"))
-setMethod("|", c("logical", "CrunchExpr"), vxv("or"))
-setMethod("|", c("CrunchExpr", "logical"), vxv("or"))
-
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("!", c("CrunchExpr"),
     function (x) {
         CrunchLogicalExpr(expression=zfunc("not", x),
             dataset_url=datasetReference(x))
     })
 
-##' @importFrom utils head tail
+#' @importFrom utils head tail
 .seqCrunch <- function (x, table) {
     ## Given x %in% table, if table is numeric, see if we can/should collapse
     ## it into a range query rather than sending lots of distinct values
@@ -181,12 +162,12 @@ setMethod("!", c("CrunchExpr"),
     math.exp(x, table, ifelse(length(table) == 1L, "==", "in"))
 }
 
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("CategoricalVariable", "character"),
-    function (x, table) .inCrunch(x, n2i(table, categories(x))))
-##' @rdname expressions
-##' @export
+    function (x, table) .inCrunch(x, n2i(table, categories(x), strict=FALSE)))
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("CategoricalVariable", "factor"),
     function (x, table) x %in% as.character(table))
 
@@ -195,33 +176,77 @@ for (i in seq_along(.sigs)) {
     setMethod("%in%", .sigs[[i]], .inCrunch)
 }
 
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("TextVariable", "character"), .inCrunch)
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("NumericVariable", "numeric"), .inCrunch)
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("DatetimeVariable", "Date"), .inCrunch)
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("DatetimeVariable", "POSIXt"), .inCrunch)
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
+setMethod("%in%", c("DatetimeVariable", "character"), .inCrunch)
+#' @rdname expressions
+#' @export
 setMethod("%in%", c("CategoricalVariable", "numeric"), .inCrunch)
 
+for (i in c("==", "!=")) {
+    for (j in seq_along(.sigs)) {
+        setMethod(i, .sigs[[j]], crunch.ops(i))
+        setMethod(i, rev(.sigs[[j]]), crunch.ops(i)) ## is this right?
+    }
+    for (j in .rtypes) {
+        setMethod(i, c("CrunchExpr", j), crunch.ops(i))
+        setMethod(i, c(j, "CrunchExpr"), crunch.ops(i))
+    }
+    setMethod(i, c("CrunchVariable", "CrunchVariable"), crunch.ops(i))
+    setMethod(i, c("CrunchExpr", "CrunchVariable"), crunch.ops(i))
+    setMethod(i, c("CrunchVariable", "CrunchExpr"), crunch.ops(i))
+}
+
+## Use %in% because it handles the possibility that e2 is not a valid category
+
+#' @rdname expressions
+#' @export
+setMethod("==", c("CategoricalVariable", "character"),
+    function (e1, e2) e1 %in% e2)
+#' @rdname expressions
+#' @export
+setMethod("==", c("CategoricalVariable", "factor"),
+    function (e1, e2) e1 %in% e2)
+#' @rdname expressions
+#' @export
+setMethod("!=", c("CategoricalVariable", "character"), function (e1, e2) {
+    e2 <- n2i(e2, categories(e1), strict=FALSE)
+    neq <- length(e2) == 1
+    out <- math.exp(e1, e2, ifelse(neq, "!=", "in"))
+    if (!neq) {
+        ## We did "in" above, so make that "not in"
+        out <- !out
+    }
+    return(out)
+})
+#' @rdname expressions
+#' @export
+setMethod("!=", c("CategoricalVariable", "factor"),
+    function (e1, e2) e1 != as.character(e2))
+
 setMethod("datasetReference", "CrunchExpr", function (x) x@dataset_url)
 
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 setMethod("is.na", "CrunchVariable", function (x) {
     CrunchLogicalExpr(expression=zfunc("is_missing", x),
         dataset_url=datasetReference(x))
 })
 
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 bin <- function (x) {
     ## TODO: this should be filtered by x's filter
     CrunchExpr(expression=zfunc("bin", x),
@@ -229,8 +254,8 @@ bin <- function (x) {
 }
 
 
-##' @rdname expressions
-##' @export
+#' @rdname expressions
+#' @export
 rollup <- function (x, resolution=rollupResolution(x)) {
     valid_res <- c("Y", "Q", "M", "W", "D", "h", "m", "s", "ms")
     force(resolution)
@@ -255,8 +280,8 @@ rollupResolution <- function (x) {
     }
 }
 
-##' @rdname variable-extract
-##' @export
+#' @rdname variable-extract
+#' @export
 setMethod("[", c("CrunchExpr", "CrunchLogicalExpr"), function (x, i, ...) {
     f <- activeFilter(x)
     if (length(zcl(f))) {
