@@ -7,7 +7,12 @@ setMethod("initialize", "ShojiCatalog", function (.Object, ...) {
 is.catalog <- function (x) inherits(x, "ShojiCatalog")
 
 getIndexSlot <- function (x, i, what=character(1), ifnot=NA_character_) {
-    vapply(index(x), function (a) a[[i]] %||% ifnot, what, USE.NAMES=FALSE)
+    getListSlot(index(x), i, what, ifnot)
+}
+
+getListSlot <- function (x, i, what=character(1), ifnot=NA_character_) {
+    ## Wrapper to vapply over a list data structure and select a value
+    vapply(x, function (a) a[[i]] %||% ifnot, what, USE.NAMES=FALSE)
 }
 
 setIndexSlot <- function (x, i, value, unique=FALSE) {
@@ -47,8 +52,8 @@ dirtyElements <- function (x, y) {
     !mapply(identical, x, y, USE.NAMES=FALSE, SIMPLIFY=TRUE)
 }
 
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[", c("ShojiCatalog", "character"), function (x, i, ...) {
     w <- whichNameOrURL(x, i)
     if (any(is.na(w))) {
@@ -56,8 +61,8 @@ setMethod("[", c("ShojiCatalog", "character"), function (x, i, ...) {
     }
     return(x[w])
 })
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[", c("ShojiCatalog", "numeric"), function (x, i, ...) {
     bad <- abs(as.integer(i)) > length(x)
     if (any(bad)) {
@@ -65,8 +70,8 @@ setMethod("[", c("ShojiCatalog", "numeric"), function (x, i, ...) {
     }
     callNextMethod(x, i, value)
 })
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[", c("ShojiCatalog", "logical"), function (x, i, ...) {
     if (length(i) > length(x)) {
         halt("Subscript out of bounds: got ", length(i), " logicals, need ",
@@ -75,20 +80,20 @@ setMethod("[", c("ShojiCatalog", "logical"), function (x, i, ...) {
     index(x) <- index(x)[i]
     return(x)
 })
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[", c("ShojiCatalog", "ANY"), function (x, i, ...) {
     index(x) <- index(x)[i]
     return(x)
 })
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[[", c("ShojiCatalog", "ANY"), function (x, i, ...) {
     index(x)[[i]]
 })
 
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[[", c("ShojiCatalog", "character"), function (x, i, ...) {
     stopifnot(length(i) == 1L)
     w <- whichNameOrURL(x, i)
@@ -98,19 +103,19 @@ setMethod("[[", c("ShojiCatalog", "character"), function (x, i, ...) {
     index(x)[[w]]
 })
 
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("$", "ShojiCatalog", function (x, name) x[[name]])
 
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("$<-", "ShojiCatalog", function (x, name, value) {
     x[[name]] <- value
     return(x)
 })
 
-##' @rdname catalog-extract
-##' @export
+#' @rdname catalog-extract
+#' @export
 setMethod("[<-", c("ShojiCatalog", "ANY", "missing", "ShojiCatalog"),
     function (x, i, j, value) {
         index(x)[i] <- index(value)[i]
@@ -118,10 +123,10 @@ setMethod("[<-", c("ShojiCatalog", "ANY", "missing", "ShojiCatalog"),
         return(x)
     })
 
-##' Length of Catalog
-##' @param x a Catalog
-##' @return Integer: the number of elements in the index list
-##' @name catalog-length
+#' Length of Catalog
+#' @param x a Catalog
+#' @return Integer: the number of elements in the index list
+#' @name catalog-length
 NULL
 
 whichNameOrURL <- function (x, i, secondary=names(x)) {
@@ -142,76 +147,76 @@ whichNameOrURL <- function (x, i, secondary=names(x)) {
     return(w)
 }
 
-##' @rdname catalog-length
-##' @export
+#' @rdname catalog-length
+#' @export
 setMethod("length", "ShojiCatalog", function (x) length(index(x)))
 setMethod("lapply", "ShojiCatalog", function (X, FUN, ...) lapply(index(X), FUN, ...))
 
-##' Get the body of a Catalog
-##'
-##' The core of Catalog data is in its "index". These methods get and set that
-##' slot.
-##' @param x a Catalog (VariableCatalog, Subvariables, or similar object)
-##' @param value For the setters, an appropriate-length list to
-##' assign
-##' @return Getters return the list object in the "index" slot; setters
-##' return \code{x} duly modified.
-##' @aliases index index<-
-##' @name index
+#' Get the body of a Catalog
+#'
+#' The core of Catalog data is in its "index". These methods get and set that
+#' slot.
+#' @param x a Catalog (VariableCatalog, Subvariables, or similar object)
+#' @param value For the setters, an appropriate-length list to
+#' assign
+#' @return Getters return the list object in the "index" slot; setters
+#' return \code{x} duly modified.
+#' @aliases index index<-
+#' @name index
 NULL
 
-##' @rdname index
-##' @export
+#' @rdname index
+#' @export
 setMethod("index", "ShojiCatalog", function (x) x@index)
-##' @rdname index
-##' @export
+#' @rdname index
+#' @export
 setMethod("index<-", "ShojiCatalog", function (x, value) {
     x@index <- value
     return(x)
 })
 
-##' Get the URLs contained in a Catalog or Order object
-##'
-##' Sometimes it is useful to extract flattened vector of URLs from more
-##' complex objects for purposes like subsetting or doing set comparisons.
-##'
-##' @param x a Catalog, Order, or Group object
-##' @return A character vector of URLs
-##' @aliases urls
-##' @keywords internal
-##' @rdname urls
-##' @export
+#' Get the URLs contained in a Catalog or Order object
+#'
+#' Sometimes it is useful to extract flattened vector of URLs from more
+#' complex objects for purposes like subsetting or doing set comparisons.
+#'
+#' @param x a Catalog, Order, or Group object
+#' @return A character vector of URLs
+#' @aliases urls
+#' @keywords internal
+#' @rdname urls
+#' @export
 setMethod("urls", "ShojiCatalog", function (x) names(index(x)))
 
-##' @rdname describe-catalog
-##' @export
+#' @rdname describe-catalog
+#' @export
 setMethod("names", "ShojiCatalog", function (x) getIndexSlot(x, "name"))
-##' @export
-##' @rdname describe-catalog
+#' @export
+#' @rdname describe-catalog
 setMethod("names<-", "ShojiCatalog", function (x, value) {
     setIndexSlot(x, "name", value, unique=TRUE)
 })
 
-##' @rdname describe-catalog
-##' @export
+#' @rdname describe-catalog
+#' @export
 setMethod("emails", "ShojiCatalog", function (x) getIndexSlot(x, "email"))
 
-##' @export
+#' @export
 as.list.ShojiCatalog <- function (x, ...) lapply(names(index(x)), function (i) x[[i]])
 
-##' Utility to get a more human-readable view of a Shoji Catalog
-##'
-##' @param x ShojiCatalog or subclass
-##' @param keys character vector of attribute names from each catalog tuple to
-##' include in the result. Default is TRUE, which means all.
-##' @param rownames See \code{\link[base]{data.frame}}, the \code{row.names}
-##' argument, to which this is passed in \code{data.frame}. The difference here
-##' is that if \code{rownames} is explicitly set as \code{NULL}, the resulting
-##' object will not have row names set. By default, row names will be the URLs
-##' of the catalog tuples.
-##' @param ... additional arguments passed to \code{data.frame}
-##' @return a \code{data.frame} view of the catalog
-##' @export
+#' Utility to get a more human-readable view of a Shoji Catalog
+#'
+#' @param x ShojiCatalog or subclass
+#' @param keys character vector of attribute names from each catalog tuple to
+#' include in the result. Default is TRUE, which means all.
+#' @param rownames See \code{\link[base]{data.frame}}, the \code{row.names}
+#' argument, to which this is passed in \code{data.frame}. The difference here
+#' is that if \code{rownames} is explicitly set as \code{NULL}, the resulting
+#' object will not have row names set. By default, row names will be the URLs
+#' of the catalog tuples.
+#' @param ... additional arguments passed to \code{data.frame}
+#' @return a \code{data.frame} view of the catalog
+#' @export
 catalogToDataFrame <- function (x, keys=TRUE, rownames, ...) {
     default.rownames <- missing(rownames)
     if (default.rownames) {
