@@ -1,34 +1,34 @@
-##' Subvariables in Array Variables
-##'
-##' Multiple-response and categorical-array variables contain a set of
-##' subvariables within them. The Subvariables class encapsulates them.
-##'
-##' Subvariables can be accessed from array variables (including multiple
-##' response) with the \code{subvariables} method. They can be assigned back
-##' with the \code{subvariables<-} setter, but there are limitations to what
-##' is supported. Specifically, you can reorder subvariables, but you cannot
-##' add or remove subvariables by \code{subvariables<-} assignment. See
-##' \code{\link{deleteSubvariable}} to remove subvariables from an array.
-##'
-##' Subvariables have a \code{names} attribute that can be accessed, showing
-##' the display names of the subvariables. These can be set with the
-##' \code{names<-} method.
-##'
-##' Finally, subvariables can be accessed as regular (categorical) variables
-##' with the \code{$} and \code{[[} extract methods.
-##'
-##' See the vignette on array variables for further details and examples.
-##'
-##' @param x A Variable or Subvariables object
-##' @param value For the setters, the appropriate values to set
-##'
-##' @name Subvariables
-##' @aliases Subvariables subvariables subvariables<-
-##' @seealso \code{\link{subvars-extract}} \code{\link{describe-catalog}} \code{\link{deleteSubvariable}} \code{vignette("array-variables", package="crunch")}
+#' Subvariables in Array Variables
+#'
+#' Multiple-response and categorical-array variables contain a set of
+#' subvariables within them. The Subvariables class encapsulates them.
+#'
+#' Subvariables can be accessed from array variables (including multiple
+#' response) with the \code{subvariables} method. They can be assigned back
+#' with the \code{subvariables<-} setter, but there are limitations to what
+#' is supported. Specifically, you can reorder subvariables, but you cannot
+#' add or remove subvariables by \code{subvariables<-} assignment. See
+#' \code{\link{deleteSubvariable}} to remove subvariables from an array.
+#'
+#' Subvariables have a \code{names} attribute that can be accessed, showing
+#' the display names of the subvariables. These can be set with the
+#' \code{names<-} method.
+#'
+#' Finally, subvariables can be accessed as regular (categorical) variables
+#' with the \code{$} and \code{[[} extract methods.
+#'
+#' See the vignette on array variables for further details and examples.
+#'
+#' @param x A Variable or Subvariables object
+#' @param value For the setters, the appropriate values to set
+#'
+#' @name Subvariables
+#' @aliases Subvariables subvariables subvariables<-
+#' @seealso \code{\link{subvars-extract}} \code{\link{describe-catalog}} \code{\link{deleteSubvariable}} \code{vignette("array-variables", package="crunch")}
 NULL
 
-##' @rdname Subvariables
-##' @export
+#' @rdname Subvariables
+#' @export
 setMethod("subvariables", "CategoricalArrayVariable", function (x) {
     tup <- tuple(x)
     catalog_url <- absoluteURL(tup$subvariables_catalog, base=tup@index_url)
@@ -38,21 +38,21 @@ setMethod("subvariables", "CategoricalArrayVariable", function (x) {
     return(out)
 })
 
-##' @rdname Subvariables
-##' @export
+#' @rdname Subvariables
+#' @export
 setMethod("subvariables", "VariableTuple", function (x) {
     ## Return subvariable *urls* from a Tuple, properly formatted and absolute
     return(absoluteURL(unlist(x$subvariables), base=x@index_url))
 })
 
-##' @rdname Subvariables
-##' @export
+#' @rdname Subvariables
+#' @export
 setMethod("subvariables<-", c("CategoricalArrayVariable", "ANY"),
     function (x, value) {
         halt("Can only assign an object of class Subvariables")
     })
-##' @rdname Subvariables
-##' @export
+#' @rdname Subvariables
+#' @export
 setMethod("subvariables<-", c("CategoricalArrayVariable", "Subvariables"),
     function (x, value) {
         old <- subvariables(tuple(x))
@@ -61,7 +61,7 @@ setMethod("subvariables<-", c("CategoricalArrayVariable", "Subvariables"),
             halt("Can only reorder, not change, subvariables")
         }
         new <- I(new)
-        if (!is.readonly(x) && !identical(new, I(old))) {
+        if (!identical(new, I(old))) {
             body <- list(subvariables=new)
             payload <- toJSON(body)
             crPATCH(self(x), body=payload)
@@ -71,14 +71,14 @@ setMethod("subvariables<-", c("CategoricalArrayVariable", "Subvariables"),
         return(x)
     })
 
-##' @rdname describe-catalog
-##' @export
+#' @rdname describe-catalog
+#' @export
 setMethod("aliases", "Subvariables", function (x) {
     vapply(index(x), function (a) a$alias, character(1), USE.NAMES=FALSE)
 })
 
-##' @rdname describe-catalog
-##' @export
+#' @rdname describe-catalog
+#' @export
 setMethod("aliases<-", "Subvariables", function (x, value) {
     stopifnot(is.character(value), length(x) == length(value),
         !any(duplicated(value)))
@@ -90,29 +90,29 @@ setMethod("aliases<-", "Subvariables", function (x, value) {
     return(x)
 })
 
-##' Extract and modify subsets of subvariables
-##'
-##' @param x Subvariables or an array Variable (which contains subvariables)
-##' @param i which subvariables to extract
-##' @param name For \code{$}, the name (not alias) of the subvariable to
-##' extract
-##' @param j Invalid
-##' @param drop Invalid
-##' @param ... additional arguments
-##' @param value For updating, a CrunchExpr
-##' @return A subset of \code{x} if extracting, otherwise \code{x} duly modified
-##' @name subvars-extract
+#' Extract and modify subsets of subvariables
+#'
+#' @param x Subvariables or an array Variable (which contains subvariables)
+#' @param i which subvariables to extract
+#' @param name For \code{$}, the name (not alias) of the subvariable to
+#' extract
+#' @param j Invalid
+#' @param drop Invalid
+#' @param ... additional arguments
+#' @param value For updating, a CrunchExpr
+#' @return A subset of \code{x} if extracting, otherwise \code{x} duly modified
+#' @name subvars-extract
 NULL
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[", c("Subvariables", "character"), function (x, i, ...) {
     i <- match(i, names(x))
     if (is.na(i)) return(NULL)
     return(x[[i, ...]])
 })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[", c("Subvariables", "ANY"), function (x, i, ...) {
     out <- callNextMethod(x, i, ...)
     if (!is.null(out)) {
@@ -121,8 +121,8 @@ setMethod("[[", c("Subvariables", "ANY"), function (x, i, ...) {
     return(out)
 })
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[", c("Subvariables", "character"), function (x, i, ...) {
     w <- match(i, names(x))
     if (any(is.na(w))) {
@@ -131,15 +131,16 @@ setMethod("[", c("Subvariables", "character"), function (x, i, ...) {
     return(x[w])
 })
 
-##' Delete subvariables from an array
-##'
-##' This function conceals the dirty work in making this happen. The array
-##' gets unbound, the subvariables deleted, and then the remaining subvariable
-##' are rebound into a new array.
-##' @param variable the array variable
-##' @param to.delete subvariable names to delete
-##' @return a new version of variable without the indicated subvariables
-##' @export
+#' Delete subvariables from an array
+#'
+#' This function conceals the dirty work in making this happen. The array
+#' gets unbound, the subvariables deleted, and then the remaining subvariable
+#' are rebound into a new array.
+#' @param variable the array variable
+#' @param to.delete character alias(es) or name(s), depending on the value of
+#' \code{getOption("crunch.namekey.array")}, of the subvariables to delete.
+#' @return a new version of variable without the indicated subvariables
+#' @export
 deleteSubvariables <- function (variable, to.delete) {
     ## Store some metadata up front
     payload <- copyVariableReferences(variable)
@@ -149,7 +150,7 @@ deleteSubvariables <- function (variable, to.delete) {
 
     ## Identify subvariable URLs
     delete.these <- findVariableURLs(subvariables(variable), to.delete,
-        key="name")
+        key=namekey(variable))
     ## Unbind
     all.subvar.urls <- unlist(unbind(variable))
 
@@ -171,12 +172,12 @@ deleteSubvariables <- function (variable, to.delete) {
     invisible(new_url)
 }
 
-##' @rdname deleteSubvariables
-##' @export
+#' @rdname deleteSubvariables
+#' @export
 deleteSubvariable <- deleteSubvariables
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[<-",
     c("Subvariables", "character", "missing", "CrunchVariable"),
     function (x, i, value) {
@@ -192,8 +193,8 @@ setMethod("[[<-",
         x[[i]] <- value ## "callNextMethod"
         return(x)
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[<-",
     c("Subvariables", "ANY", "missing", "CrunchVariable"),
     function (x, i, value) {
@@ -203,23 +204,23 @@ setMethod("[[<-",
         index(x)[[self(value)]] <- tuple(value)@body
         return(x)
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[<-",
     c("Subvariables", "ANY", "missing", "NULL"),
     function (x, i, value) {
         halt("Cannot add or remove subvariables")
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[<-",
     c("Subvariables", "ANY", "missing", "ANY"),
     function (x, i, value) {
         halt("Can only assign Variables into an object of class Subvariables")
     })
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[<-", c("Subvariables", "character", "missing", "Subvariables"),
     function (x, i, value) {
         w <- match(i, names(x))
@@ -228,8 +229,8 @@ setMethod("[<-", c("Subvariables", "character", "missing", "Subvariables"),
         }
         callNextMethod(x, w, value)
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[<-", c("Subvariables", "ANY", "missing", "Subvariables"),
     function (x, i, value) {
         inbound <- vapply(value, function (a) self(a), character(1))
@@ -240,25 +241,25 @@ setMethod("[<-", c("Subvariables", "ANY", "missing", "Subvariables"),
         names(index(x))[i] <- inbound
         return(x)
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[<-", c("Subvariables", "ANY", "missing", "ANY"),
     function (x, i, value) {
         halt("Can only assign Variables into an object of class Subvariables")
     })
 
-##' @export
+#' @export
 as.list.Subvariables <- function (x, ...) lapply(names(x), function (i) x[[i]])
 
 
-##' @rdname describe-catalog
-##' @export
+#' @rdname describe-catalog
+#' @export
 setMethod("names", "CategoricalArrayVariable", function (x) {
     getIndexSlot(subvariables(x), namekey(x))
 })
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[", c("CategoricalArrayVariable", "character"), function (x, i, ...) {
     w <- match(i, names(x))
     if (any(is.na(w))) {
@@ -266,34 +267,34 @@ setMethod("[", c("CategoricalArrayVariable", "character"), function (x, i, ...)
     }
     return(subvariables(x)[w, ...])
 })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[", c("CategoricalArrayVariable", "ANY"), function (x, i, ...) {
     return(subvariables(x)[[i, ...]])
 })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[", c("CategoricalArrayVariable", "character"), function (x, i, ...) {
     i <- match(i, names(x))
     if (is.na(i)) return(NULL)
     return(x[[i, ...]])
 })
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("$", "CategoricalArrayVariable", function (x, name) x[[name]])
 
 
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[<-",
     c("CategoricalArrayVariable", "ANY", "missing", "ANY"),
     function (x, i, value) {
         subvariables(x)[[i]] <- value
         return(x)
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("[[<-",
     c("CategoricalArrayVariable", "character", "missing", "ANY"),
     function (x, i, value) {
@@ -309,8 +310,8 @@ setMethod("[[<-",
         subvariables(x)[[i]] <- value ## "callNextMethod"
         return(x)
     })
-##' @rdname subvars-extract
-##' @export
+#' @rdname subvars-extract
+#' @export
 setMethod("$<-", c("CategoricalArrayVariable"), function (x, name, value) {
     x[[name]] <- value
     return(x)
