@@ -19,7 +19,9 @@ with_mock_HTTP({
         expect_identical(activeFilter(ds2), ds$gender == "Male")
     })
     test_that("Active filter persists on refreshing dataset", {
-        expect_identical(activeFilter(refresh(ds2)), ds$gender == "Male")
+        ## Compare @expressions because of a quirk of the mock backend
+        expect_identical(activeFilter(refresh(ds2))@expression,
+            (ds$gender == "Male")@expression)
     })
     test_that("Further [ on a filtered dataset ands the filters together", {
         expect_identical(activeFilter(ds3),
@@ -32,8 +34,7 @@ with_mock_HTTP({
 
     test_that("Variables extracted from a filtered dataset are also filtered", {
         expect_identical(activeFilter(ds2$birthyr), ds$gender == "Male")
-        skip("Not really supporting this correctly")
-        expect_identical(ds[ds$gender == "Male", "birthyr"],
+        expect_identical(activeFilter(ds[ds$gender == "Male", "birthyr"]),
             ds$gender == "Male")
     })
 
@@ -53,7 +54,7 @@ with_mock_HTTP({
 
     test_that("Getting weight variable from filtered dataset is filtered", {
         ds4 <- ds2
-        ds4@body$weight <- "/api/datasets/dataset1/variables/starttime.json"
+        ds4@body$weight <- "/api/datasets/dataset1/variables/starttime/"
         expect_identical(weight(ds4), ds4$starttime)
         expect_identical(activeFilter(weight(ds4)), ds$gender == "Male")
     })
@@ -67,15 +68,31 @@ with_mock_HTTP({
     })
 
     test_that("activeFilter from CrunchExpr", {
-        ## Need the @expression here because CrunchExpr@filter is list
         expect_identical(activeFilter((ds$birthyr - ds$starttime)[ds$gender == "Male"]),
-            (ds$gender == "Male")@expression)
+            ds$gender == "Male")
     })
     test_that("activeFilter passes across operations among vars/exprs", {
-        skip("TODO: filtered variables/exprs should pass their filters along")
         expect_identical(activeFilter(ds$birthyr[ds$gender == "Male"] - ds$starttime[ds$gender == "Male"]),
             ds$gender == "Male")
     })
+    test_that("Vars with different activeFilters can't combine", {
+        expect_error(ds$birthyr[ds$gender == "Male"] - ds$starttime[ds$gender == "Female"],
+            "Cannot combine expressions with different filters")
+    })
+    test_that("Exprs with different activeFilters can't combine", {
+        expect_error((ds$birthyr - ds$starttime)[ds$gender == "Male"] - (ds$birthyr - ds$starttime)[ds$gender == "Female"],
+            "Cannot combine expressions with different filters")
+    })
+    test_that("Vars/exprs together with different active filters can't combine", {
+        expect_error(ds$birthyr[ds$gender == "Male"] - (ds$birthyr - ds$starttime)[ds$gender == "Female"],
+            "Cannot combine expressions with different filters")
+    })
+    test_that("Can combine var with activeFilter with non-Crunch object", {
+        expect_identical(activeFilter(ds$birthyr[ds$gender == "Male"] - 50),
+            ds$gender == "Male")
+        expect_identical(activeFilter(2016 - ds$birthyr[ds$gender == "Male"]),
+            ds$gender == "Male")
+    })
 })
 
 if (run.integration.tests) {
@@ -96,7 +113,7 @@ if (run.integration.tests) {
             test_that("activeFilter appears in print method for dataset", {
                 expect_output(ds3, "Filtered by v3 > 11")
                 expect_false(any(grepl("Filtered by",
-                    capture.output(print(ds)))))
+                    get_output(ds))))
             })
 
             test_that("Filtered variables return filtered values from as.vector", {
