@@ -7,6 +7,29 @@ test_that("Deprecated endpoints tell user to upgrade", {
               "Please upgrade crunch to the latest version."))
 })
 
+with_mock_HTTP({
+    test_that("crunch.debug does not print if disabled", {
+        expect_POST(
+            expect_output(crPOST("/api/", body='{"value":1}'),
+                NA),
+            "/api/",
+            '{"value":1}')
+    })
+    test_that("crunch.debug logging if enabled", {
+        with(temp.option(crunch.debug=TRUE), {
+            expect_POST(
+                expect_output(crPOST("/api/", body='{"value":1}'),
+                    '\n {"value":1} \n',
+                    fixed=TRUE),
+                "/api/",
+                '{"value":1}')
+            ## Use testthat:: so that it doesn't print ds. Check for log printing
+            testthat::expect_output(ds <- loadDataset("test ds"),
+                NA)
+        })
+    })
+})
+
 if (run.integration.tests) {
     test_that("Request headers", {
         skip_on_jenkins("Don't fail the build if httpbin is down")
@@ -26,13 +49,13 @@ if (run.integration.tests) {
 
     with_test_authentication({
         test_that("API root can be fetched", {
-            expect_true(is.shojiObject(getAPIroot()))
+            expect_true(is.shojiObject(getAPIRoot()))
         })
     })
 
     test_that("API calls throw an error if user is not authenticated", {
         logout()
-        expect_error(getAPIroot(),
+        expect_error(getAPIRoot(),
             "You are not authenticated. Please `login\\(\\)` and try again.")
     })
 }
