@@ -1,7 +1,7 @@
 context("Derive a new variable")
 
 if (run.integration.tests) {
-    with(test.authentication, {
+    with_test_authentication({
         with(test.dataset(df), {
             try(ds$v3a <- ds$v3 + 5)
             test_that("A derived variable is created on the server", {
