@@ -3,12 +3,11 @@ context("Deleting rows of a dataset")
 with_mock_HTTP({
     ds <- loadDataset("test ds")
     test_that("dropRows generates the right request", {
-        expect_error(dropRows(ds, ds$gender == "Male"),
-            paste0('POST /api/datasets/dataset1/table.json ',
+        expect_POST(dropRows(ds, ds$gender == "Male"),
+            '/api/datasets/dataset1/table/',
             '{"command":"delete","filter":{"function":"==",',
-            '"args":[{"variable":"/api/datasets/dataset1/variables/gender.json"},',
-            '{"value":1}]}}'),
-            fixed=TRUE)
+            '"args":[{"variable":"/api/datasets/dataset1/variables/gender/"},',
+            '{"value":1}]}}')
     })
 })
 
