@@ -44,8 +44,8 @@ test_that("ShojiCatalog", {
 })
 
 with_mock_HTTP({
-    full.urls <- DatasetCatalog(crGET("/api/datasets.json"))
-    rel.urls <- DatasetCatalog(crGET("/api/datasets-relative-urls.json"))
+    full.urls <- DatasetCatalog(crGET("/api/datasets/"))
+    rel.urls <- DatasetCatalog(crGET("/api/datasets-relative-urls/"))
     test_that("urls() method returns absolute URLs", {
         expect_identical(urls(full.urls), urls(rel.urls))
     })
@@ -53,24 +53,22 @@ with_mock_HTTP({
     test_that("shojiURL", {
         ds <- loadDataset("test ds")
         expect_identical(shojiURL(ds, "catalogs", "variables"),
-            "/api/datasets/dataset1/variables.json")
+            "/api/datasets/dataset1/variables/")
         expect_error(shojiURL(ds, "catalogs", "NOTACATALOG"),
             paste0("No URL ", dQuote("NOTACATALOG"), " in collection ",
             dQuote("catalogs")))
     })
 })
 
-if (run.integration.tests) {
-    with_test_authentication({
-        with(test.dataset(df), {
-            test_that("refresh", {
-                expect_identical(ds, refresh(ds))
-                ds2 <- ds
-                ds2@body$name <- "something else"
-                expect_false(identical(ds2, ds))
-                expect_false(identical(ds2, refresh(ds2)))
-                expect_identical(refresh(ds2), ds)
-            })
+with_test_authentication({
+    with(test.dataset(df), {
+        test_that("refresh", {
+            expect_identical(ds, refresh(ds))
+            ds2 <- ds
+            ds2@body$name <- "something else"
+            expect_false(identical(ds2, ds))
+            expect_false(identical(ds2, refresh(ds2)))
+            expect_identical(refresh(ds2), ds)
         })
     })
-}
+})
