@@ -26,10 +26,10 @@ if (run.integration.tests) {
 
         with(test.dataset(newDatasetFromFixture("apidocs")), {
             test_that("Can update an individual subvariable conditionally", {
-                expect_equivalent(as.vector(ds$allpets$Cat, mode="id")[1:5],
+                expect_equivalent(as.vector(ds$allpets$allpets_1, mode="id")[1:5],
                     c(1, 9, 1, 1, 9))
-                ds$allpets$Cat[2] <- 1
-                expect_equivalent(as.vector(ds$allpets$Cat, mode="id")[1:5],
+                ds$allpets$allpets_1[2] <- 1
+                expect_equivalent(as.vector(ds$allpets$allpets_1, mode="id")[1:5],
                     c(1, 1, 1, 1, 9))
             })
         })
